# feeluown 本地音乐插件

## 安装

```sh
pip3 install fuo-local
```

## TODO

此插件目前功能非常基础，有很多可以改进的地方，从功能到性能。
下面列了一些可以改进的方面：

- [ ] 支持自定义歌曲目录
- [ ] 增量扫描？
- [ ] 支持更多格式的音乐
- ...

## changelog
### 0.1.1 (2019-03-23)
- 适配 feeluown 3.0a5+

### 0.1 (2019-03-18)
- 支持扫描 `~/Music` 目录的本地音乐
